@@ -328,6 +328,13 @@ var documentsMain = {
 			return;
 		}
 
+		var pollUrl = documentsMain.isGuest 
+				? OC.generateUrl('apps/documents/session/guest/poll/{token}', {'token' : $("[name='document']").val()})
+				: OC.generateUrl('apps/documents/session/user/poll'),
+			saveUrl = documentsMain.isGuest 
+				? OC.generateUrl('apps/documents/session/guest/save/{token}', {'token' : $("[name='document']").val()})
+				: OC.generateUrl('apps/documents/session/user/save')
+				;
 		documentsMain.canShare = !documentsMain.isGuest
 				&& typeof OC.Share !== 'undefined' && response.permissions & OC.PERMISSION_SHARE;
 		require({ }, ["owncloud/ServerFactory", "webodf/editor/Editor"], function (ServerFactory, Editor) {
@@ -347,8 +354,10 @@ var documentsMain = {
 				documentsMain.memberId = response.member_id;
 
 				// TODO: set webodf translation system, by passing a proper function translate(!string):!string in "runtime.setTranslator(translate);"
-
-				documentsMain.webodfServerInstance = serverFactory.createServer();
+				documentsMain.webodfServerInstance = serverFactory.createServer({
+					url : pollUrl,
+					sessionStateToFileUrl : saveUrl
+				});
 				documentsMain.webodfServerInstance.setToken(oc_requesttoken);
 				documentsMain.webodfEditorInstance = new Editor(
 						{
@@ -383,9 +392,9 @@ var documentsMain = {
 		console.log('joining session '+fileId);
 		var url;
 		if (documentsMain.isGuest){
-			url = OC.generateUrl('apps/documents/ajax/session/joinasguest/{token}', {token: fileId});
+			url = OC.generateUrl('apps/documents/session/guest/join/{token}', {token: fileId});
 		} else {
-			url = OC.generateUrl('apps/documents/ajax/session/joinasuser/{file_id}', {file_id: fileId});
+			url = OC.generateUrl('apps/documents/session/user/join/{file_id}', {file_id: fileId});
 		}
 		$.post(
 			url,
@@ -665,6 +674,13 @@ FileList.getCurrentDirectory = function(){
 	return $('#dir').val() || '/';
 };
 
+FileList.setViewerMode = function(){
+};
+FileList.findFile = function(fileName){
+	fullPath = escapeHTML(FileList.getCurrentDirectory + '/' + fileName);
+	return !!$('.documentslist .document:not(.template,.progress) a[original-title="' + fullPath + '"]').length
+}
+
 $(document).ready(function() {
 	documentsMain.docs = $('.documentslist').documentGrid();
 	documentsMain.overlay = $('<div id="documents-overlay" class="icon-loading"></div><div id="documents-overlay-below" class="icon-loading-dark"></div>').documentOverlay();
@@ -686,6 +702,10 @@ $(document).ready(function() {
 	
 	$('.add-document').on('click', '.add', documentsMain.onCreate);
 
+	OC.Upload._isReceivedSharedFile = function () {
+		return false;
+	}
+
 	var file_upload_start = $('#file_upload_start');
 	if (typeof supportAjaxUploadWithProgress !== 'undefined' && supportAjaxUploadWithProgress()) {
 		file_upload_start.on('fileuploadstart', function(e, data) {
